/*
*  Rubrica
*  file: browse.h
*  
*  Copyright (C) 2000-2001 Nicola Fragale <nicolafragale@libero.it>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef _RUBRICA_BROWSE_H
#define _RUBRICA_BROWSE_H

#include <gtk/gtk.h>

#include "app.h"


/*    funzioni per la navigazione  tra le schede inserite
*/

void rubrica_browse_first_card    (RubricaApp* app);
void rubrica_browse_last_card     (RubricaApp* app);
void rubrica_browse_next_card     (RubricaApp* app);
void rubrica_browse_previous_card (RubricaApp* app);
void rubrica_browse_nth_card      (RubricaApp* app, gchar *path_str);


#endif
